function [S1,S2,d]=subarrays(sensor)
%SUBARRAYS selection matrices for two identical subarrays
%   S1,S2   selection matrices
%   d       normalized displacement
%   sensor  radar sensor device

c0=299792458; % speed of light

switch sensor.mode
    case {'adisimo','adisimofile'}
        S1=horzcat(eye(3),zeros(3,1));
        S2=horzcat(zeros(3,1),eye(3));
        d=0.5;
        
    case {'adimimo','adimimofile'}
        S1=vertcat(horzcat(eye(4),zeros(4)),horzcat(zeros(2,5),eye(2),zeros(2,1)));
        S2=vertcat(horzcat(zeros(3,1),eye(3),zeros(3,4)),horzcat(zeros(3,5),eye(3)));
        d=0.5;

    case {'rfbsimo','rfbsimofile'}
        S1=horzcat(eye(3),zeros(3,1));
        S2=horzcat(zeros(3,1),eye(3));
        d=-0.0024638*(sensor.startfrequency*1e6+ ...
            sensor.slope*1e9*sensor.samples/sensor.samplerate/1e3/2)/c0;
        
    case {'rfbmimo','rfbmimofile'}
        S1=vertcat(horzcat(eye(7),zeros(7,5)),horzcat(zeros(3,8),eye(3),zeros(3,1)));
        S2=vertcat(horzcat(zeros(3,1),eye(3),zeros(3,8)),horzcat(zeros(1,8),1,zeros(1,3)), ...
            horzcat(zeros(3,5),eye(3),zeros(3,4)),horzcat(zeros(3,9),eye(3)));
        d=-0.0024638*(sensor.startfrequency*1e6+ ...
            sensor.slope*1e9*sensor.samples/sensor.samplerate/1e3/2)/c0;
        
    otherwise
    	error('unsupported mode');
end

end
